Test website

This page contains URL encoding test(s).

## Image with non-encoded chars in name with non-encoded special chars in link

An image should be displayed below

## Image with non-encoded chars in name and already encoded special chars

An image should be displayed below

## Image with non-encoded chars in name and a mix of non-encoded and already encoded special chars

An image should be displayed below

## Image with non-encoded chars in name with non-encoded special chars in link and a query parameter and fragment with reserved chars

An image should be displayed below as well

## Image with already encoded chars in name with non-encoded special chars in link

This is not working on source website, so should not work in ZIM

## Image with already encoded chars in name and already encoded special chars in link

This is not working on source website, so should not work in ZIM

## Image with already encoded chars in name and a mix of non-encoded and already encoded special chars in link

This is not working on source website, so should not work in ZIM

## Image with a mix of non-encoded and already encoded special chars in name with non-encoded special chars in link

This is not working on source website, so should not work in ZIM

## Image with a mix of non-encoded and already encoded special chars in name and already encoded special chars in link

This is not working on source website, so should not work in ZIM

## Image with a mix of non-encoded and already encoded special chars in name and a mix of non-encoded and already encoded special chars in link

This is not working on source website, so should not work in ZIM

## Image with many weird characters

An image should be displayed below

## Image with UTF-8 characters

An image should be displayed below

## Hostname with UTF-8 chars and simple image

An image should be displayed below

## Hostname with UTF-8 chars and image with UTF-8 chars

An image should be displayed below

## Hostname with UTF-8 chars and query parameter 1

An image should be displayed below with a 1 in the right

## Hostname with UTF-8 chars and query parameter 2

An image should be displayed below with a 2 in the right